bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 2. Aventiure
___________________________________________________ #### Aventivre von sivride #### wie der erzogen wart
###### 20 | ### Do wuohs in niderlanden | eins vil edelen kvneges kint ### des vater der hiez sigemvnt | sin mvoter sigelint ### in einer richen bverge | witen wol bechant ### nidene bi dem rine | div was ze santen genant
###### 21 | ### sivrit was geheizen | der snelle degen gvot ### er versvochte vil der riche | dvrch ellenthaften mvot ### dvrh sines libes sterche | er reit in menegiv lant ### hey waz er sneller degene | sit cen bvrgonden vant
###### 22 | ### in sinen besten ziten | bi sinen ivngen tagen ### man mohte michel wunder | von siveride sagen ### waz eren an im wuechse | vnt wi scoene was sin lip ### sit heten in ce minne | div vil waetlichen wip
###### 23 | ### man zoch in mit dem vlize | als im daz wol gezam ### von sin selbes mvote | waz tvgende er an sich nam ### des wurden sit gezieret | sines vater lant ### daz man in ze allen dingn | so rehte herlichen vant
###### 24 | ### er was nv so gewachsen | daz er ze hove reit ### di livte in sahen gerne | manech frovwe vnt manech meit ### im wunschten daz sin wille | in immer trvege dar ### holt wurden im genvoge | des wart der herre wol gewar
###### 25 | ### vil selten ane hvote | man riten lie daz kint ### in hiez mit chleidern ziern | sigmvnt vnt siglint ### sin phlagen ovch di wisen | den ere was bechant ### des moht er wol gewinnen | beide livte vnde lant
###### 26 | ### nv was er in der sterche | daz er wol wafen trvoch ### swes er darzvo bedorfte | des lag an im genvoch ### er begvnde mit sinnen | werben scoeniv wip ### di trvten wol mit eren | des chvenen sivrides lip
###### 27 | ### do hiez sin vater sigmvnt | chvnden sinen man ### er wolde hohgecite | mit liebn vriwenden han ### div maere man do fvorte | in ander chvnege lant ### den vremden vnt den chvnden | gab er ross vnt gvot gewant
###### 28 | ### swa man vant deheinen | der riter solte sin ### von art der sinen mage | div edeln kindelin ### div ladet man zvo dem lande | dvrh di hohgecit ### mit dem ivngen kvnege | swert genamen si sit
###### 29 | ### von der hohgecite | man mohte wunder sagn ### sigmvnt vnde siglint | di mohten wol beiagn ### mit gvote michel ere | des teilte vil ir hant ### des sach man vil der werden | nv zin riten in daz lant
###### 30 | ### vier hvndert swertdegene | di solden tragn chleit ### mit samt sivride | vil manech scoeniv meit ### von werche was vnmvezech | wan si im waren holt ### vil der edelen steine | die frovwen leiten in daz golt
###### 31 | ### die si mit porten wolten | wurchen vf ir wat ### den ivngen stolzen rechen | des ne was niht rat ### der wirt der hiez do sideln | vil manegn chvenen man ### ce einen svnewenden | da sin svn sivrid wol riters namn gewan
###### 32 | ### do gie ce einem mvenster | vil manech richer chneht ### vnt manech edel riter | di wisen hetn reht ### daz si den tvmben dienten | als in was e getan ### si heten chvrzewile | vnd ovch vil maneger vrevden wan
###### 33 | ### got man do cen ern | eine messe sanch ### do hvop sih von den livten | vil michel der gedranch ### da si ce riter wurden | nah riterlicher e ### mit also grozen ern | daz waetlich immer mer erge
###### 34 | ### si liefen da si fvnden | gesatelt manech march ### in hove sigmvndes | der bvhvrt wart so starch ### daz man erdiezen horte | palas vnde sal ### di hohgemvoten degene | di heten grozlichen schal
###### 35 | ### von wisen vnt von tvmben | man horte manegen stoz ### daz der scefte brechen | gein den lveften doz ### trvonzvne sach man vliegen | fver den palas dan ### von maneges rechen hende | daz wart mit vlize getan
###### 36 | ### der wirt der bat ez lazen | do zoch man div march ### man sach ovch da cebrochen | vil manege bvkel starch ### vil der edelen steine | gevellet vf daz gras ### ab liehten schildes spangen | von hverten daz gescehen was
###### 37 | ### do giengens wirtes geste | da man in sizzen riet ### vil der edelen spise | si von ir mvede sciet ### vnt win der allerbeste | des man in vil getrvoch ### den vremden vnt den chvnden | bot man ern genvoch
###### 38 | ### swi vil si chvrzwile | pflagn al den tach ### vil der varender diete | ruowe sich bewach ### si dienten nach der gabe | di man da riche vant ### des wart mit lobe gezieret | allez sigmvnds lant
###### 39 | ### der herre der hiez lihen | sivrit den ivngen man ### lant vnde bvrge | als er het e getan ### sinen swertgenozen | den gap do vil sin hant ### do liebt in div reise | daz si chomn in daz lant
###### 40 | ### div hohgecit div werte | vnz an den sibenden tach ### siglint div riche | nach alten siten pflach ### dvrh ir svns liebe | teilen rotez golt ### si chvndez wol gedienen | daz im div livte waren holt
###### 41 | ### vil lvcel man der varnder | armen da vant ### ross vnd chleider | daz stovb in von der hant ### sam si ce lebne heten | niht mer deheinen tach ### ich waen ie ingesinde | so grozer milte gepflach
###### 42 | ### mit loblichen eren | sciet sich div hohgecit ### von den richen herrn | horte man wol sit ### daz si den ivngen wolden | ce eime herren han ### des en gerte niht her sivrit | der vil waetliche man
###### 43 | ### sit daz noch beide lebten | sigmvnt vnt siglint ### niht wolde tragen chrone | ir beider liebez chint ### doch wolder wesen herre | fver allen den gewalt ### des in den landen vorhte | der degen chven vnd balt

<<< Übersicht <<< vorige Seite nächste Seite >>>